==> readmore-2.2.0.tar.gz: example/test/widget_test.dart <==
// This is a basic Flutter widget test.
//
// To perform an interaction with a widget in your test, use the WidgetTester
// utility that Flutter provides. For example, you can send tap and scroll
// gestures. You can also use WidgetTester to find child widgets in the widget
// tree, read text, and verify that the values of widget properties are correct.

import 'package:example/main.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  testWidgets('Counter increments smoke test', (WidgetTester tester) async {
    // Build our app and trigger a frame.
    await tester.pumpWidget(MyApp());

    final finderShowMore = find.byWidgetPredicate(
      (widget) => widget is RichText && tapTextSpan(widget, "...Show more"),
    );

    final finderShowLess = find.byWidgetPredicate(
      (widget) => widget is RichText && tapTextSpan(widget, " show less"),
    );

    // Verify that our counter starts at 0.
    expect(finderShowMore, findsOneWidget);
    expect(finderShowLess, findsNothing);
  });
}

final finder = find.byWidgetPredicate(
  (widget) => widget is RichText && tapTextSpan(widget, "bbb "),
);

bool findTextAndTap(InlineSpan visitor, String text) {
  if (visitor is TextSpan && visitor.text == text) {
    (visitor.recognizer as TapGestureRecognizer).onTap?.call();

    return false;
  }

  return true;
}

bool tapTextSpan(RichText richText, String text) {
  final isTapped = !richText.text.visitChildren(
    (visitor) => findTextAndTap(visitor, text),
  );

  return isTapped;
}

==> readmore-3.0.0.tar.gz: example/test/widget_test.dart <==
// This is a basic Flutter widget test.
//
// To perform an interaction with a widget in your test, use the WidgetTester
// utility that Flutter provides. For example, you can send tap and scroll
// gestures. You can also use WidgetTester to find child widgets in the widget
// tree, read text, and verify that the values of widget properties are correct.

import 'package:example/main.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  testWidgets('Counter increments smoke test', (WidgetTester tester) async {
    // Build our app and trigger a frame.
    await tester.pumpWidget(const MyApp());

    final finderShowMore = find.byWidgetPredicate(
      (widget) => widget is RichText && tapTextSpan(widget, '...Show more'),
    );

    final finderShowLess = find.byWidgetPredicate(
      (widget) => widget is RichText && tapTextSpan(widget, ' show less'),
    );

    // Verify that our counter starts at 0.
    expect(finderShowMore, findsOneWidget);
    expect(finderShowLess, findsNothing);
  });
}

bool findTextAndTap(InlineSpan visitor, String text) {
  if (visitor is TextSpan && visitor.text == text) {
    (visitor.recognizer! as TapGestureRecognizer).onTap?.call();

    return false;
  }

  return true;
}

bool tapTextSpan(RichText richText, String text) {
  final isTapped = !richText.text.visitChildren(
    (visitor) => findTextAndTap(visitor, text),
  );

  return isTapped;
}
